@@ -26,9 +26,12 @@ pub use role::RoleExt;
 pub use role_binding::RoleBindingExt;
 pub use role_ref::RoleRefExt;
 pub use secret::SecretExt;
+pub use secret_volume_source::SecretVolumeSourceExt;
 pub use service::ServiceExt;
 pub use service_account::ServiceAccountExt;
 pub use subject::SubjectExt;
+pub use volume::VolumeExt;
+pub use volume_mount::VolumeMountExt;
 
 mod cluster_role;
 mod cluster_role_binding;
@@ -47,9 +50,12 @@ mod role;
 mod role_binding;
 mod role_ref;
 mod secret;
+mod secret_volume_source;
 mod service;
 mod service_account;
 mod subject;
+mod volume;
+mod volume_mount;
 
 pub trait ResourceExt {
     fn metadata(name: impl ToString) -> metav1::ObjectMeta {
