@@ -131,6 +131,61 @@ impl Kubectl {
         Ok(object)
     }
 
+    pub async fn ensure_global_k_is_installed_forced<K>(&self, mut object: K) -> kube::Result<K>
+    where
+        K: kube::ResourceExt + ser::Serialize + de::DeserializeOwned + Clone + fmt::Debug,
+        <K as kube::Resource>::DynamicType: Default,
+    {
+        let name = object.name();
+        let objects = self.api::<K>();
+        if let Ok(existing) = objects.get(&name).await {
+            object.meta_mut().resource_version = existing.resource_version();
+        }
+
+        let object = self.force_patch(object, objects).await?;
+
+        Ok(object)
+    }
+
+    pub async fn ensure_namespaced_k_is_installed_forced<K>(
+        &self,
+        mut object: K,
+        namespace: &str,
+    ) -> kube::Result<K>
+    where
+        K: kube::Resource + ser::Serialize + de::DeserializeOwned + Clone + fmt::Debug,
+        <K as kube::Resource>::DynamicType: Default,
+    {
+        let name = object.name();
+        let objects = self.namespaced_api::<K>(namespace);
+        if let Ok(existing) = objects.get(&name).await {
+            object.meta_mut().resource_version = existing.resource_version();
+        }
+
+        let object = self.force_patch(object, objects).await?;
+
+        Ok(object)
+    }
+
+    pub async fn ensure_default_namespaced_k_is_installed_forced<K>(
+        &self,
+        mut object: K,
+    ) -> kube::Result<K>
+    where
+        K: kube::Resource + ser::Serialize + de::DeserializeOwned + Clone + fmt::Debug,
+        <K as kube::Resource>::DynamicType: Default,
+    {
+        let name = object.name();
+        let objects = self.default_namespaced_api::<K>();
+        if let Ok(existing) = objects.get(&name).await {
+            object.meta_mut().resource_version = existing.resource_version();
+        }
+
+        let object = self.force_patch(object, objects).await?;
+
+        Ok(object)
+    }
+
     pub async fn get_k_logs<K>(&self, object: &K) -> kube::Result<String>
     where
         K: kube::Resource + api::Log + de::DeserializeOwned,
