@@ -59,6 +59,17 @@ impl super::Kubectl {
         api.patch(&name, &pp, &patch).await
     }
 
+    pub async fn force_patch<K>(&self, object: K, api: kube::Api<K>) -> kube::Result<K>
+    where
+        K: kube::Resource + ser::Serialize + de::DeserializeOwned + Clone + fmt::Debug,
+        <K as kube::Resource>::DynamicType: Default,
+    {
+        let name = object.name();
+        let patch = api::Patch::Apply(&object);
+        let pp = self.patch_with_manager(&self.manager).force();
+        api.patch(&name, &pp, &patch).await
+    }
+
     pub fn api<T>(&self) -> api::Api<T>
     where
         T: kube::Resource,
