@@ -44,9 +44,12 @@ pub use ext::RoleBindingExt;
 pub use ext::RoleExt;
 pub use ext::RoleRefExt;
 pub use ext::SecretExt;
+pub use ext::SecretVolumeSourceExt;
 pub use ext::ServiceAccountExt;
 pub use ext::ServiceExt;
 pub use ext::SubjectExt;
+pub use ext::VolumeExt;
+pub use ext::VolumeMountExt;
 
 pub use kubectl::Kubectl;
 
